@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.0103';
+our $VERSION = '0.0104';
 
 use Encode qw(encode_utf8);
 use Crypt::Passphrase::Argon2 ();
@@ -60,7 +60,7 @@ DBIx::Class::EncodedColumn::Crypt::Passphrase::Argon2 - Crypt::Passphrase::Argon
 
 =head1 VERSION
 
-version 0.0103
+version 0.0104
 
 =head1 SYNOPSIS
 
@@ -130,7 +130,7 @@ Return a coderef that, when given a resultset object and a plain text value, wil
 return a boolean if the plain text matches the encoded value. This is typically
 used for password authentication.
 
-  $result->check_password($pass);
+  $authed = $result->check_password($pass);
 
 =head1 SEE ALSO
 
